detectStill method
Detects the most prominent face in a still image (photo mode). Null when unsupported or no face found.
Implementation
@override
Future<TrackingData?> detectStill(Uint8List bytes) async => stillResult;
Detects the most prominent face in a still image (photo mode). Null when unsupported or no face found.
@override
Future<TrackingData?> detectStill(Uint8List bytes) async => stillResult;